<?php
/**
 * @file
 * Allows the site to send and receive user contacts to and from Text Marketer.
 */

use Drupal\textmarketer_contacts\Controller\Request;

/**
 * Connects to Text Marketer and prepares the data.
 *
 * @return array
 *   Returns an array of matching and non-matching results.
 */

/**
 * Builds a table of matching user details.
 *
 * @return string
 *   Returns markup and the themed table.
 *
 * @throws \Exception
 *   Returns a notice if no matching numbers found.
 */
function textmarketer_contacts_import_contacts() {
  $output = '<h4>' . t('Contacts matching the site users will be listed in a
  table.') . '</h4>';
  $request = new Request();
  list($matching_results, $non_matching)
    = $request->importContacts();

  if ($matching_results) {
    $output .= '<div class="textmarketer-download-csv">' . l(t('Dowload CSV'),
        'admin/config/services/textmarketer-send-contacts/export-contacts') .
      '</div>';
    // Build the table header and rows.
    $header = array(
      'Telephone',
      'User ID',
      'Username',
      'Email address',
      'Created',
    );
    $rows = array();

    drupal_set_message(t('We found @matching @users with matching
      mobile number, and @non_matching @numbers did not match any users.',
      array(
        '@matching' => count($matching_results),
        '@non_matching' => count($non_matching),
        '@users' => format_plural(count($matching_results), 'user', 'users'),
        '@numbers' => format_plural(count($non_matching), 'number', 'numbers'),
      )), 'notice');

    foreach ($matching_results as $user_details) {
      foreach ($user_details as $row) {
        if ($row->uid > 0) {
          $rows[] = array(
            check_plain($row->telephone),
            $row->entity_id,
            l($row->name, 'user/' . $row->entity_id . '/edit'),
            $row->mail,
            date('d F Y', $row->created),
          );
        }
      }
    }
    $output .= theme('table', array(
      'header' => $header,
      'rows' => $rows,
    ));
    // Add a pager.
    $output .= theme('pager');
  }
  else {
    drupal_set_message(t('There were no matching results.'), 'warning');
  }

  return $output;
}

/**
 * Prepares the CSV file and forces a file download.
 */
function textmarketer_contacts_export_contacts() {
  list($matching_results) = textmarketer_contacts_prepare_results();

  foreach ($matching_results as $result) {
    foreach ($result as $user) {
      $user_details[] = $user;
    }
  }

  // Sends response headers to the browser.
  drupal_add_http_header('Content-Type', 'text/csv');
  drupal_add_http_header('Content-Disposition',
    'attachment;filename=csvfile.csv');

  $fp = fopen('php://output', 'w');
  // Build the columns.
  fputcsv($fp, array('Number', 'Username', 'Email'));

  foreach ($user_details as $row) {
    unset($row->uid);
    unset($row->created);
    fputcsv($fp, (array) $row);
  }
  fclose($fp);
  drupal_exit();
}
